@@ -409,7 +409,7 @@ def save_to_xls(data_list: Optional[List[list]] = None, headers: Optional[List[s
         print(f"Data not saved due to missing arguments: {', '.join(missing_args)}")
 
 
-def save_to_db(data_list: Optional[List[list]] = None, headers: Optional[List[str]] = None, db_file_path: str = "data.sqlite", table_name: str = "data", auto_data_type: bool = False) -> None:
+def save_to_db(data_list: Optional[List[list]] = None, headers: Optional[List[str]] = None, output_file_path: str = "data.sqlite", table_name: str = "data", auto_data_type: bool = False) -> None:
     """
     Saves data to an SQLite database. If the table exists, it appends the data; otherwise, it creates a new table.
     Handles type detection, smart appending, automatically adds missing columns with default empty string values.
@@ -417,7 +417,7 @@ def save_to_db(data_list: Optional[List[list]] = None, headers: Optional[List[st
     Args:
     - data_list (Optional[List[list]]): The data to be saved in the database.
     - headers (Optional[List[str]]): The column headers for the table.
-    - db_file_path (str, optional): The path to the SQLite database file. Defaults to "data.sqlite".
+    - output_file_path (str, optional): The path to the SQLite database file. Defaults to "data.sqlite".
     - table_name (str, optional): The name of the table to save data. Defaults to "data".
     - auto_data_type (bool, optional): If True, detect column types automatically. Defaults to False.
 
@@ -435,10 +435,10 @@ def save_to_db(data_list: Optional[List[list]] = None, headers: Optional[List[st
 
     try:
         # Ensure the directory for the database exists
-        dir_name = get_dir_by_path(file_path=db_file_path)
+        dir_name = get_dir_by_path(file_path=output_file_path)
         create_directory(directory_name=dir_name)
 
-        conn = sqlite3.connect(db_file_path)
+        conn = sqlite3.connect(output_file_path)
         cursor = conn.cursor()
 
         def detect_type(value):
@@ -501,7 +501,7 @@ def save_to_db(data_list: Optional[List[list]] = None, headers: Optional[List[st
 
         conn.commit()
         conn.close()
-        # print(f"Saved {len(data_list)} rows to '{table_name}' in '{db_file_path}'.")
+        # print(f"Saved {len(data_list)} rows to '{table_name}' in '{output_file_path}'.")
 
     except Exception as e:
         print(f"save_to_db: {e.__class__} - {str(e)}")
